@@ -417,9 +417,11 @@ class NodeBuilder:
 
         self.schema = schema
         self.query_type = schema.query_type
-        self.immutable_fields = self.query_type.fields[
-            self.node_config.get_function_name
-        ].args.keys()
+        self.immutable_fields = []
+        if self.node_config.get_function_name:
+            self.immutable_fields = self.query_type.fields[
+                self.node_config.get_function_name
+            ].args.keys()
 
         self.mutation_type = schema.mutation_type
 
@@ -656,6 +658,10 @@ async def gerror(self, {params_str}) -> {self.node_name}:
             python_line = f"{arg_name}: {parse_to_python(gql_type=arg.type)} = None"
             f_str = f"""
 def {arg_name}(self, {python_line}, /) -> {self.resolver_name}:
+    if {arg_name} is not None:
+        if not issubclass({arg_name}.__class__, BaseModel):
+            if hasattr({arg_name}, "to_pydantic"):
+                {arg_name} = {arg_name}.to_pydantic()
     self.query_params.{arg_name} = {arg_name}
     return self
             """
