@@ -4,7 +4,7 @@ import json
 import time
 from pydantic import BaseModel, PrivateAttr
 from fastapi.encoders import jsonable_encoder
-from .gql import GQLException
+from dgraph_orm import GQLException
 from .execute import gql
 from devtools import debug
 
