@@ -4,7 +4,7 @@ import json
 from pydantic import BaseModel, Field
 from fastapi.encoders import jsonable_encoder
 from . import execute
-from .gql import GQLException
+from dgraph_orm import GQLException
 from .node import Node, Params
 
 
